@@ -9,7 +9,6 @@
 # See LICENSE for details.
 # ---------------------------------------------------------------------------
 from . import exc
-from .mock import MockInfo
 
 
 def assert_satisfied(*mocks):
@@ -26,8 +25,8 @@ def assert_satisfied(*mocks):
 
     def iter_unsatisfied_expectations(mocks):
         for mock in mocks:
-            for mock_info in MockInfo(mock).walk():
-                yield from (x for x in mock_info.expectations() if not x.is_satisfied())
+            for child in mock.__m_walk__():
+                yield from (x for x in child.__m_expectations__() if not x.is_satisfied())
 
     unsatisfied_expectations = list(iter_unsatisfied_expectations(mocks))
     if unsatisfied_expectations:
